<?php

class HoursController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column2';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
            'postOnly + delete', // we only allow deletion via POST request
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array(''),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array(''),
                'users' => array('@'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('admin', 'delete', 'index', 'view', 'create', 'update','transformDB' ,'generate', 'countHours', 'genRequest', 'genSemester', 'showWeekHours', 'showHour', 'removeDuplicity', 'updateBulk'),
                'users' => array('admin.sam@bighuggym.com'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        $model = new Hours;

        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if (isset($_POST['Hours'])) {
            $model->attributes = $_POST['Hours'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->ID));
        }

        $this->render('create', array(
            'model' => $model,
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);

        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if (isset($_POST['Hours'])) {
            $model->attributes = $_POST['Hours'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->ID));
        }

        $this->render('update', array(
            'model' => $model,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        $this->loadModel($id)->delete();

        // if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
        if (!isset($_GET['ajax']))
            $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
        $dataProvider = new CActiveDataProvider('Hours');
        $this->render('index', array(
            'dataProvider' => $dataProvider,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new Hours('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['Hours']))
            $model->attributes = $_GET['Hours'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer $id the ID of the model to be loaded
     * @return Hours the loaded model
     * @throws CHttpException
     */
    public function loadModel($id) {
        $model = Hours::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param Hours $model the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'hours-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

    /**
     * Custom hours generation functionality
     */
    public function actionGenerate() {
        $this->render('generate');
    }

    public function actionGenSemester() {
        $semesters = Semesters::model()->findAll();
        $enl = Enlist::model()->with('iDK', 'iDTimet')->findAll(array('order' => 'iDTimet.week_day'));

        if (isset($_POST['semID'])) {

            $enld1 = Enlist::model()->with(array('iDK', 'iDTimet' => array('condition' => 'iDTimet.week_day=1')))->findAll();
            $enld2 = Enlist::model()->with(array('iDK', 'iDTimet' => array('condition' => 'iDTimet.week_day=2')))->findAll();
            $enld3 = Enlist::model()->with(array('iDK', 'iDTimet' => array('condition' => 'iDTimet.week_day=3')))->findAll();
            $enld4 = Enlist::model()->with(array('iDK', 'iDTimet' => array('condition' => 'iDTimet.week_day=4')))->findAll();
            $enld5 = Enlist::model()->with(array('iDK', 'iDTimet' => array('condition' => 'iDTimet.week_day=5')))->findAll();
            $enld6 = Enlist::model()->with(array('iDK', 'iDTimet' => array('condition' => 'iDTimet.week_day=6')))->findAll();
            $enld7 = Enlist::model()->with(array('iDK', 'iDTimet' => array('condition' => 'iDTimet.week_day=7')))->findAll();

            function removeInactive($idKID) { /* returns aray of kids of inactive users => users who are signed up to test hour */
                $val = false;
                $kid = Kids::model()->with(array('parrent'))->findByPk($idKID);
                if ($kid->parrent->active == 0) {
                    $val = true;
                }
                return $val;
            }

            $aendl = array($enld1, $enld2, $enld3, $enld4, $enld5, $enld6, $enld7);

            foreach ($aendl as $cnedl) {
                foreach ($cnedl as $num => $one) {
                    if (removeInactive($one->ID_kid)) {
                        //unset($one[$num]); //nefunguje
                        /* treba odstranit dieta ktore ma v buducnosti skusobnu hodinu */
                    }
                }
            }

            date_default_timezone_set('CET');

            $sem = Semesters::model()->findByPk($_POST['semID']);
            $holiday = Holiday::model()->findAll();
            $hol_array = array();

            foreach ($holiday as $hd) {
                $date_ = $hd->date_start;
                if (isset($hd->date_end)) {
                    $end_date_ = $hd->date_end;
                } else {
                    $end_date_ = $hd->date_start;
                }
                while (strtotime($date_) <= strtotime($end_date_)) {
                    $hol_array[] = $date_;
                    $date_ = date("Y-m-d", strtotime("+1 day", strtotime($date_)));
                }
            }


            $response = array();


            $date = $sem->date_start;
            $end_date = $sem->date_end;

            $classes = Classes::model()->findall();

            function insertHour($single, $date, $classes) {
                $mod = new Hours('GenSemester');
                $mod->date = $date;
                $mod->ID_timet = $single->ID_timet;
                $mod->week_day = $single->iDTimet->week_day;
                $mod->time_start = $single->iDTimet->time_start;
                $mod->time_end = $single->iDTimet->time_end;
                foreach($classes as $class){
                    if ($class->ID == $single->iDTimet->lesson){
                        $mod->lesson = $class->name;
                    }
                }
                $mod->trainer = $single->iDTimet->trainer;
                $mod->trainer_alt = $single->iDTimet->trainer_alt;
                $mod->ID_kids = $single->ID_kid;
                $mod->name = $single->iDK->name;
                $mod->surname = $single->iDK->surname;
                $mod->present = 0;
                $mod->tryout = 0;
                $mod->notes = NULL;
                if ($mod->validate()) {
                    if ($mod->save()) {
                        return $mod;
                    }
                }
            }

            $i = 0;

            while (strtotime($date) <= strtotime($end_date)) {
                if (!(in_array($date, $hol_array))) {
                    switch (date('D', strtotime($date))) {
                        case 'Mon':
                            //echo ' pondelok<br >';
                            foreach ($aendl[0] as $single) {
                                $response[] = insertHour($single, $date, $classes);
                            }
                            break;
                        case 'Tue':
                            //echo ' utorok<br />';
                            foreach ($aendl[1] as $single) {
                                $response[] = insertHour($single, $date, $classes);
                            }
                            break;
                        case 'Wed':
                            foreach ($aendl[2] as $single) {
                                $response[] = insertHour($single, $date, $classes);
                            }
                            break;
                        case 'Thu':
                            foreach ($aendl[3] as $single) {
                                $response[] = insertHour($single, $date, $classes);
                            }
                            break;
                        case 'Fri':
                            foreach ($aendl[4] as $single) {
                                $response[] = insertHour($single, $date, $classes);
                            }
                            break;
                        case 'Sat':
                            foreach ($aendl[5] as $single) {
                                $response[] = insertHour($single, $date, $classes);
                            }
                            break;
                        case 'Sun':
                            foreach ($aendl[6] as $single) {
                                $response[] = insertHour($single, $date, $classes);
                            }
                            break;
                    }
                }
                $date = date("Y-m-d", strtotime("+1 day", strtotime($date)));
            } //koniec while
        }//koniec isset post
        if (isset($response)) {
            Yii::app()->user->setFlash('success', "Hodiny boli úspešne vygenerované.");
//            sleep(2);
//            $model = new Hours('search');
//            $model->unsetAttributes();  // clear any default values
//            if (isset($_GET['Hours']))
//                $model->attributes = $_GET['Hours'];

            $this->redirect(array('hours/admin'));

        } else {
            $this->render('genSemester', array('sem' => $semesters, 'enl' => $enl,));
        }
    }

    public function actionTransformDB(){
        $hours = Hours::model()->findAll(array(
            'order' => 'ID DESC',
            'condition'=>'date >= :date',
            'params'=>array(':date'=>'2018-01-01'),
        ));

        foreach ($hours as $hour){
            switch ($hour->lesson) {
                case 'hrosikovia':
                    $hour->lesson ='hrošíkovia';
                    $hour->save();
                    break;
                case 'zabky':
                    $hour->lesson = 'žabky';
                    $hour->save();
                    break;
                case 'zajacikovia':
                    $hour->lesson = 'zajačikovia';
                    $hour->save();
                    break;
                case 'orangutani':
                    $hour->lesson = 'orangutani';
                    $hour->save();
                    break;
                case 'gepardi':
                    $hour->lesson = 'gepardi';
                    $hour->save();
                    break;
                case 'levy':
                    $hour->lesson = 'levy';
                    $hour->save();
                    break;


                default:
                    break;
            }
        }
    }

    public function actionGenRequest() {
        $kids = Kids::model()->findAll(array('order' => 'surname'));
        $enl = Enlist::model()->with('iDK', 'iDTimet')->findAll(array('order' => 'iDTimet.week_day'));

        if ((isset($_POST['end_date'])) && (isset($_POST['start_date']))) {

            if ((isset($_POST['ID_kid'])) && ($_POST['ID_kid'] != "")) {
                $enld1 = Enlist::model()->with(array('iDK' => array('condition' => 'iDK.ID=' . $_POST['ID_kid']), 'iDTimet' => array('condition' => 'iDTimet.week_day=1')))->findAll();
                $enld2 = Enlist::model()->with(array('iDK' => array('condition' => 'iDK.ID=' . $_POST['ID_kid']), 'iDTimet' => array('condition' => 'iDTimet.week_day=2')))->findAll();
                $enld3 = Enlist::model()->with(array('iDK' => array('condition' => 'iDK.ID=' . $_POST['ID_kid']), 'iDTimet' => array('condition' => 'iDTimet.week_day=3')))->findAll();
                $enld4 = Enlist::model()->with(array('iDK' => array('condition' => 'iDK.ID=' . $_POST['ID_kid']), 'iDTimet' => array('condition' => 'iDTimet.week_day=4')))->findAll();
                $enld5 = Enlist::model()->with(array('iDK' => array('condition' => 'iDK.ID=' . $_POST['ID_kid']), 'iDTimet' => array('condition' => 'iDTimet.week_day=5')))->findAll();
                $enld6 = Enlist::model()->with(array('iDK' => array('condition' => 'iDK.ID=' . $_POST['ID_kid']), 'iDTimet' => array('condition' => 'iDTimet.week_day=6')))->findAll();
                $enld7 = Enlist::model()->with(array('iDK' => array('condition' => 'iDK.ID=' . $_POST['ID_kid']), 'iDTimet' => array('condition' => 'iDTimet.week_day=7')))->findAll();
            } else {
                $enld1 = Enlist::model()->with(array('iDK', 'iDTimet' => array('condition' => 'iDTimet.week_day=1')))->findAll();
                $enld2 = Enlist::model()->with(array('iDK', 'iDTimet' => array('condition' => 'iDTimet.week_day=2')))->findAll();
                $enld3 = Enlist::model()->with(array('iDK', 'iDTimet' => array('condition' => 'iDTimet.week_day=3')))->findAll();
                $enld4 = Enlist::model()->with(array('iDK', 'iDTimet' => array('condition' => 'iDTimet.week_day=4')))->findAll();
                $enld5 = Enlist::model()->with(array('iDK', 'iDTimet' => array('condition' => 'iDTimet.week_day=5')))->findAll();
                $enld6 = Enlist::model()->with(array('iDK', 'iDTimet' => array('condition' => 'iDTimet.week_day=6')))->findAll();
                $enld7 = Enlist::model()->with(array('iDK', 'iDTimet' => array('condition' => 'iDTimet.week_day=7')))->findAll();
            }
            date_default_timezone_set('CET');

            //$sem = Semesters::model()->findByPk($_POST['semID']);
            $holiday = Holiday::model()->findAll();
            $hol_array = array();

            foreach ($holiday as $hd) {
                $date_ = $hd->date_start;
                if (isset($hd->date_end)) {
                    $end_date_ = $hd->date_end;
                } else {
                    $end_date_ = $hd->date_start;
                }
                while (strtotime($date_) <= strtotime($end_date_)) {
                    $hol_array[] = $date_;
                    $date_ = date("Y-m-d", strtotime("+1 day", strtotime($date_)));
                }
            }

            $response = array();

            $date = $_POST['start_date'];
            $end_date = $_POST['end_date'];

            $classes = Classes::model()->findAll();

            function insertHour($single, $date, $classes) {
                $mod = new Hours('GenSemester');
                $mod->date = $date;
                $mod->ID_timet = $single->ID_timet;
                $mod->week_day = $single->iDTimet->week_day;
                $mod->time_start = $single->iDTimet->time_start;
                $mod->time_end = $single->iDTimet->time_end;
                foreach($classes as $class){
                    if ($class->ID == $single->iDTimet->lesson){
                        $mod->lesson = $class->name;
                    }
                }
                $mod->trainer = $single->iDTimet->trainer;
                $mod->trainer_alt = $single->iDTimet->trainer_alt;
                $mod->ID_kids = $single->ID_kid;
                $mod->name = $single->iDK->name;
                $mod->surname = $single->iDK->surname;
                $mod->present = 0;
                $mod->tryout = 0;
                $mod->notes = NULL;
                if ($mod->validate()) {
                    if ($mod->save()) {
                        return $mod;
                    }
                }
            }

            $i = 0;

            while (strtotime($date) <= strtotime($end_date)) {
                if (!(in_array($date, $hol_array))) {
                    switch (date('D', strtotime($date))) {
                        case 'Mon':
                            //echo ' pondelok<br >';
                            foreach ($enld1 as $single) {
                                $response[] = insertHour($single, $date, $classes);
                            }
                            break;
                        case 'Tue':
                            //echo ' utorok<br />';
                            foreach ($enld2 as $single) {
                                $response[] = insertHour($single, $date, $classes);
                            }
                            break;
                        case 'Wed':
                            foreach ($enld3 as $single) {
                                $response[] = insertHour($single, $date, $classes);
                            }
                            break;
                        case 'Thu':
                            foreach ($enld4 as $single) {
                                $response[] = insertHour($single, $date, $classes);
                            }
                            break;
                        case 'Fri':
                            foreach ($enld5 as $single) {
                                $response[] = insertHour($single, $date, $classes);
                            }
                            break;
                        case 'Sat':
                            foreach ($enld6 as $single) {
                                $response[] = insertHour($single, $date, $classes);
                            }
                            break;
                        case 'Sun':
                            foreach ($enld7 as $single) {
                                $response[] = insertHour($single, $date, $classes);
                            }
                            break;
                    }
                }
                $date = date("Y-m-d", strtotime("+1 day", strtotime($date)));
            } //koniec while
        }//koniec isset post
        if (isset($response)) {
            Yii::app()->user->setFlash('success', "Hodiny boli uspesne vytvorene!");
//            sleep(2);
//            $model = new Hours('search');
//            $model->unsetAttributes();  // clear any default values
//            if (isset($_GET['Hours']))
//                $model->attributes = $_GET['Hours'];
//
            $this->redirect(array('hours/admin'));

        } else {
            $this->render('genRequest', array('kids' => $kids, 'enl' => $enl,));
        }
    }

    public function actionShowWeekHours() {
        date_default_timezone_set('CET');

        $model = array();
        $date = date('Y-m-d');
        //find prev monday
        while (date('D', strtotime($date)) != 'Mon') {
            $date = date('Y-m-d', strtotime("-1 day", strtotime($date)));
        }

        $start_date = $date;
        $end_date = date('Y-m-d', strtotime("+14 day", strtotime($date)));

        while (strtotime($date) <= strtotime($end_date)) {
            $model[] = Hours::model()->findAllByAttributes(array('date' => $date));
            $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
            foreach ($model[end(array_keys($model))] as $current) {
                $model[end(array_keys($model))]['hours'][] = $current->time_start;
            }
        }

        $this->render('showWeekHours', array('thisWeek' => $model, 'startDay' => $start_date));
    }

    public function actionShowHour($date, $time) {
        $time = str_replace('-', ':', $time);
        $data = Hours::model()->findAllByAttributes(array(
            'date' => $date,
            'time_start' => $time,
        ));
        $this->render('showHour', array('data' => $data));
    }

    public function actionRemoveDuplicity() {

        $h = Hours::model()->findAll(array(
            'order' => 'ID DESC',
            'condition'=>'date >= :date',
            'params'=>array(':date'=>'2018-01-01'),
        ));
        $n = 0;


        foreach ($h as $hour) {
            $dup = Hours::model()->findAllByAttributes(array(
                // $date
                // $ID_timet
                // $week_day
                // $time_start
                // $time_end
                // $lesson
                //* $trainer
                // $ID_kids
                'ID_kids' => $hour->ID_kids,
                'date' => $hour->date,
                'ID_timet' => $hour->ID_timet,
                'week_day' => $hour->week_day,
                'time_start' => $hour->time_start,
                'time_end' => $hour->time_end,
                'lesson' => $hour->lesson,
            ));
            if (count($dup) > 1) {
                //$hour->delete();
                $n++;
            }
        }

        $this->render('removeDuplicity', array('n' => $n));
    }

   /**
     * This is the model class for table "hours".
     *
     * The followings are the available columns in table 'hours':
     * @property integer $ID
     * @property string $date
     * @property integer $ID_timet
     * @property string $week_day
     * @property string $time_start
     * @property string $time_end
     * @property string $lesson
     * @property integer $trainer
     * @property integer $trainer_alt
     * @property integer $ID_kids
     * @property string $name
     * @property string $surname
     * @property integer $present
     * @property integer $tryout
     * @property string $notes
     * @property string $cur_timestamp
     */
    function actionUpdateBulk() {
        $trainers = Users::model()->findAllByAttributes(array(
           'rights_ID'=>'3',
        ));
        $kids = Kids::model()->findAll(array("order" => "surname"));
        $tt = Timetable::model()->findAll();

        if (isset($_POST['hours']) && ($_POST['formname'] == 'hours-select-form')) {
            $attributes = array();
            $criteria = new CDbCriteria();
            $dates = array();

//            if (isset($_POST['hours']['date_to']) && trim($_POST['hours']['date_to']) != "") {
//                //$attributes['date'] = $_POST['hours']['date'];
//                $criteria->addInCondition('date', array('2016-04-01','2016-04-02'));
//            }
            if (isset($_POST['hours']['date']) && trim($_POST['hours']['date']) != "" && isset($_POST['hours']['date_to']) && trim($_POST['hours']['date_to']) != "") {
                $end = new DateTime(trim($_POST['hours']['date_to']));
                $end = $end->modify( '+1 day' );

                $period = new DatePeriod(
                new DateTime(trim($_POST['hours']['date'])),
                new DateInterval('P1D'),
                $end
                );


                foreach( $period as $solo) {
                    $dates[] = $solo->format('Y-m-d');
                }

                $criteria->addInCondition('date', $dates);


            } elseif (isset($_POST['hours']['date']) && trim($_POST['hours']['date']) != ""){
                $attributes['date'] = $_POST['hours']['date'];
            }


            if (isset($_POST['hours']['lesson']) && trim($_POST['hours']['lesson']) != "") {
                $attributes['lesson'] = $_POST['hours']['lesson'];
            }
            if (isset($_POST['hours']['ID_timet']) && trim($_POST['hours']['ID_timet']) != '') {
                $attributes['ID_timet'] = $_POST['hours']['ID_timet'];
            }
            if (isset($_POST['hours']['kid_ID']) && trim($_POST['hours']['kid_ID']) != "") {
                $attributes['ID_kids'] = $_POST['hours']['kid_ID'];
            }
            if (isset($_POST['hours']['kid_name']) && trim($_POST['hours']['kid_name']) != "") {
                $attributes['name'] = $_POST['hours']['kid_name'];
            }
            if (isset($_POST['hours']['kid_surname']) && trim($_POST['hours']['kid_surname']) != "") {
                $attributes['surname'] = $_POST['hours']['kid_surname'];
            }
            if (isset($_POST['hours']['trainer_ID']) && trim($_POST['hours']['trainer_ID']) != "") {
                $attributes['trainer'] = $_POST['hours']['trainer_ID'];
            }
            if (isset($_POST['hours']['alt_trainer_ID']) && trim($_POST['hours']['alt_trainer_ID']) != "") {
                $attributes['trainer_alt'] = $_POST['hours']['alt_trainer_ID'];
            }
            if (isset($_POST['hours']['day']) && trim($_POST['hours']['day']) != "") {
                $attributes['week_day'] = $_POST['hours']['day'];
            }
//            if(isset($_POST['hours']['trimester_ID'])){
//                $attributes['trimester_ID'] = $_POST['hours']['trimester_ID'];
//            }
            if (isset($_POST['hours']['time_start']) && trim($_POST['hours']['time_start']) != "") {
                $attributes['time_start'] = $_POST['hours']['time_start'];
            }
            if (isset($_POST['hours']['time_end']) && trim($_POST['hours']['time_end']) != "") {
                $attributes['time_end'] = $_POST['hours']['time_end'];
            }

            $hourstochange = Hours::model()->findAllByAttributes($attributes, $criteria);
            $this->render('updateBulkSelected', array('htu' => $hourstochange, 'debug' => $attributes, 'cond'=>$dates, 'tt'=>$tt, 'train'=>$trainers, 'kids'=>$kids));
            // redirect!
        } elseif (isset($_POST['formname']) && $_POST['formname'] == 'hours-update-form') {
            $change = $_POST['radio'];
            $changed = array();
            $fetched = array();
            if (isset($_POST['delete-selected']) && ($_POST['delete-selected'] == 'yes')) {
                foreach ($change as $key => $value) {
                    if ($value == "yes") {
                        $fetched[] = $key;
                    }
                }
                $adjustedHours = Hours::model()->findAllByPk($fetched);
                foreach ($change as $key => $value) {
                    if ($value == "yes") {
                        $currentHour = Hours::model()->findByPk($key);
                        $adjustedHours[] = $currentHour;
                        $currentHour->delete();
                    }
                }
                $adjustedHours['deleted'] = 'deleted';
            } else {
                foreach ($change as $key => $value) {
                    if ($value == "yes") {
                        $changed[$key] = $value;
                        $currentHour = Hours::model()->findByPk($key);

                        if (isset($_POST['hours']['date']) && (trim($_POST['hours']['date']) != '')) {
                            $currentHour->date = $_POST['hours']['date'];
                        }
                        if (isset($_POST['hours']['lesson']) && (trim($_POST['hours']['lesson']) != '')) {
                            $currentHour->lesson = $_POST['hours']['lesson'];
                        }
                        if (isset($_POST['hours']['ID_timet']) && (trim($_POST['hours']['ID_timet']) != '')) {
                            $currentHour->ID_timet = $_POST['hours']['ID_timet'];
                        }
                        if (isset($_POST['hours']['kid_ID']) && (trim($_POST['hours']['kid_ID']) != '')) {
                            $currentHour->ID_kids = $_POST['hours']['kid_ID'];
                        }
                        if (isset($_POST['hours']['kid_name']) && (trim($_POST['hours']['kid_name']) != '')) {
                            $currentHour->name = $_POST['hours']['kid_name'];
                        }
                        if (isset($_POST['hours']['kid_surname']) && (trim($_POST['hours']['kid_surname']) != '')) {
                            $currentHour->surname = $_POST['hours']['kid_surname'];
                        }
                        if (isset($_POST['hours']['trainer_ID']) && (trim($_POST['hours']['trainer_ID']) != '')) {
                            $currentHour->trainer = $_POST['hours']['trainer_ID'];
                        }
                        if (isset($_POST['hours']['alt_trainer_ID']) && (trim($_POST['hours']['alt_trainer_ID']) != '')) {
                            $currentHour->trainer_alt = $_POST['hours']['alt_trainer_ID'];
                        }
                        if (isset($_POST['hours']['day']) && (trim($_POST['hours']['day']) != '')) {
                            $currentHour->week_day = $_POST['hours']['day'];
                        }
                        if (isset($_POST['hours']['time_start']) && (trim($_POST['hours']['time_start']) != '')) {
                            $currentHour->time_start = $_POST['hours']['time_start'];
                        }
                        if (isset($_POST['hours']['time_end']) && (trim($_POST['hours']['time_end']) != '')) {
                            $currentHour->time_end = $_POST['hours']['time_end'];
                        }
//                        print_r($currentHour);
                        $currentHour->save();


                    }

                    foreach ($changed as $key => $value) {
                        $fetched[] = $key;
                    }
                    $adjustedHours = Hours::model()->findAllByPk($fetched);
                }
            }
            $this->render('updateBulkSummary', array('changed' => $changed, 'adj' => $adjustedHours));
        } else {
            $this->render('updateBulk', array('tt'=>$tt, 'train'=>$trainers, 'kids'=>$kids));
        }
    }


    public function lastTrimesterID()
    {
      /**
      * returns the last ID from the db semesters
      * the last ID is expected to point to the last added semester, which should be chronologically last
      */
      $row = Yii::app()->db->createCommand()
                ->select('ID')
                ->from('semesters')
                ->order('ID DESC')
                ->queryRow();
      return $row['ID'];
    }

    function actionCountHours() {
        $trainers = Users::model()->findAllByAttributes(array(
           'rights_ID'=>'3',
        ));
        $kids = Kids::model()->findAll(array("order" => "surname"));
        $tt = Timetable::model()->findAll();

        if (isset($_POST['hours']) && ($_POST['formname'] == 'hours-select-form')) {
            $attributes = array();
            $criteria = new CDbCriteria();
            $dates = array();

//            if (isset($_POST['hours']['date_to']) && trim($_POST['hours']['date_to']) != "") {
//                //$attributes['date'] = $_POST['hours']['date'];
//                $criteria->addInCondition('date', array('2016-04-01','2016-04-02'));
//            }
            if (isset($_POST['hours']['date']) && trim($_POST['hours']['date']) != "" && isset($_POST['hours']['date_to']) && trim($_POST['hours']['date_to']) != "") {
                $end = new DateTime(trim($_POST['hours']['date_to']));
                $end = $end->modify( '+1 day' );

                $period = new DatePeriod(
                new DateTime(trim($_POST['hours']['date'])),
                new DateInterval('P1D'),
                $end
                );


                foreach( $period as $solo) {
                    $dates[] = $solo->format('Y-m-d');
                }

                $criteria->addInCondition('date', $dates);


            } elseif (isset($_POST['hours']['date']) && trim($_POST['hours']['date']) != ""){
                $attributes['date'] = $_POST['hours']['date'];
            }


            if (isset($_POST['hours']['lesson']) && trim($_POST['hours']['lesson']) != "") {
                $attributes['lesson'] = $_POST['hours']['lesson'];
            }
            if (isset($_POST['hours']['ID_timet']) && trim($_POST['hours']['ID_timet']) != '') {
                $attributes['ID_timet'] = $_POST['hours']['ID_timet'];
            }
            if (isset($_POST['hours']['kid_ID']) && trim($_POST['hours']['kid_ID']) != "") {
                $attributes['ID_kids'] = $_POST['hours']['kid_ID'];
            }
            if (isset($_POST['hours']['kid_name']) && trim($_POST['hours']['kid_name']) != "") {
                $attributes['name'] = $_POST['hours']['kid_name'];
            }
            if (isset($_POST['hours']['kid_surname']) && trim($_POST['hours']['kid_surname']) != "") {
                $attributes['surname'] = $_POST['hours']['kid_surname'];
            }
            if (isset($_POST['hours']['trainer_ID']) && trim($_POST['hours']['trainer_ID']) != "") {
                $attributes['trainer'] = $_POST['hours']['trainer_ID'];
            }
            if (isset($_POST['hours']['alt_trainer_ID']) && trim($_POST['hours']['alt_trainer_ID']) != "") {
                $attributes['trainer_alt'] = $_POST['hours']['alt_trainer_ID'];
            }
            if (isset($_POST['hours']['day']) && trim($_POST['hours']['day']) != "") {
                $attributes['week_day'] = $_POST['hours']['day'];
            }
//            if(isset($_POST['hours']['trimester_ID'])){
//                $attributes['trimester_ID'] = $_POST['hours']['trimester_ID'];
//            }
            if (isset($_POST['hours']['time_start']) && trim($_POST['hours']['time_start']) != "") {
                $attributes['time_start'] = $_POST['hours']['time_start'];
            }
            if (isset($_POST['hours']['time_end']) && trim($_POST['hours']['time_end']) != "") {
                $attributes['time_end'] = $_POST['hours']['time_end'];
            }

            $attributes['tryout'] = 0;

            $hours = Hours::model()->findAllByAttributes($attributes, $criteria);

            $kids_arr = [];

            foreach($hours as $hour){
                if(!(isset($kids_arr[$hour->ID_kids]))){
                    $kids_arr[$hour->ID_kids]['kid'] = Kids::model()->with(array('enlists', 'payments'))->findByPk($hour->ID_kids);
                    $kids_arr[$hour->ID_kids]['hours'][] = $hour;
                } else {
                    $kids_arr[$hour->ID_kids]['hours'][] = $hour;
                }
            }

            $lastTrimID = $this->lastTrimesterID();

            $this->render('countHoursSelected', array('htu' => $hours, 'debug' => $attributes, 'cond'=>$dates, 'tt'=>$tt, 'train'=>$trainers, 'kids'=>$kids, 'kids_arr'=>$kids_arr, 'lastTrimID' => $lastTrimID));
            // redirect!
        } else {
            $this->render('countHours', array('tt'=>$tt, 'train'=>$trainers, 'kids'=>$kids));
        }
    }

}
