<?php

/**
 * This is the model class for table "users".
 *
 * The followings are the available columns in table 'users':
 * @property integer $ID
 * @property string $name
 * @property string $surname
 * @property string $user_name
 * @property string $password
 * @property integer $rights_ID
 * @property string $email
 * @property string $phone_num
 * @property string $address
 * @property integer $active
 * @property integer $passsent
 * @property integer $subscribed
 * @property string $notes
 * @property string $VS
 * @property string $secure_hash
 *
 * The followings are the available model relations:
 * @property Kids[] $kids
 * @property Payments[] $payments
 * @property Timetable[] $timetables
 * @property Rights $rights
 */
class Users extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'users';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('name, surname, user_name, rights_ID, email, phone_num', 'required'),
			array('rights_ID, active, passsent, subscribed', 'numerical', 'integerOnly'=>true),
			array('name, surname, user_name, email, phone_num, address, VS', 'length', 'max'=>45),
			array('password', 'length', 'max'=>64),
                        array('secure_hash', 'length', 'max'=>32),
			array('notes', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('ID, name, surname, user_name, rights_ID, email, phone_num, address, active, passsent, subscribed, notes, VS, secure_hash', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'kids' => array(self::HAS_MANY, 'Kids', 'parrent_ID'),
			'payments' => array(self::HAS_MANY, 'Payments', 'user_ID'),
			'timetables' => array(self::HAS_MANY, 'Timetable', 'trainer'),
			'rights' => array(self::BELONGS_TO, 'Rights', 'rights_ID'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'ID' => 'ID Užívateľa',
			'name' => 'Meno',
			'surname' => 'Priezvisko',
			'user_name' => 'Používateľské meno',
			'password' => 'Heslo',
			'rights_ID' => 'Práva',
			'email' => 'Email',
			'phone_num' => 'Telefón',
			'address' => 'Adresa',
                        'active' => 'Aktívny',
                        'passsent' => 'Odoslanie hesla',
                        'subscribed' => 'Odber noviniek',
			'notes' => 'Poznámky',
			'VS' => 'Variabilný symbol',
			'secure_hash' => 'Secure Hash',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('ID',$this->ID);
		$criteria->compare('name',$this->name,true);
		$criteria->compare('surname',$this->surname,true);
		$criteria->compare('user_name',$this->user_name,true);
		//$criteria->compare('password',$this->password,true);
		$criteria->compare('rights_ID',$this->rights_ID);
		$criteria->compare('email',$this->email,true);
		$criteria->compare('phone_num',$this->phone_num,true);
		$criteria->compare('address',$this->address,true);
                $criteria->compare('active',$this->active);
                $criteria->compare('passsent',$this->passsent);
                $criteria->compare('subscribed',$this->subscribed);
		//$criteria->compare('notes',$this->notes,true);
		$criteria->compare('VS',$this->VS,true);
		//$criteria->compare('secure_hash',$this->secure_hash,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
      'pagination'=>array(
        'pageSize'=>50,
      ),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Users the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
  /**
   *  before saving convert the password and adjust them accoringly
   *  sha256 used for hashing
   */        


  public function beforeSave() 
  {
    parent::beforeSave();
    //add the password hash if it's a new record
    if ($this->isNewRecord) 
    {
       $this->password = hash('sha256', $this->password); 
       //$this->create_date=new CDbExpression("NOW()");
       //$this->password_expiry_date=new CDbExpression("DATE_ADD(NOW(), INTERVAL ".self::PASSWORD_EXPIRY." DAY) ");
    }       
    //else if (($this->password != "") && ( Yii::app()->controller->action->id == 'update' ))//(!empty($this->passwordSave)&&!empty($this->repeatPassword)&&($this->passwordSave===$this->repeatPassword)) /*TODO!*/
    //if it's not a new password, save the password only if it not empty and the two passwords match
    //{
    //   $this->password = hash('sha256', $this->password);
       //print_r( Yii::app()->controller->action->id );
       //$this->password_expiry_date=new CDbExpression("DATE_ADD(NOW(), INTERVAL ".self::PASSWORD_EXPIRY." DAY) ");
    //}
    return true;
  }  

}
